import ee
from ee_plugin import Map

Map.setCenter(lon = 18.42, lat = 47.19, zoom = 12) # Székesfehérvár
kozeppont = Map.getCenter()

egyik_landsat = ee.ImageCollection("LANDSAT/LC08/C02/T1_L2") \
	.filterBounds(kozeppont) \
	.filterDate("2022-05-01", "2022-10-31") \
	.first()

megjelenitesi_beallitasok = {
	"min": 5000,
	"max": 15000,
	"bands": ["SR_B4", "SR_B3", "SR_B2"]
}
Map.addLayer(eeObject = egyik_landsat, visParams = megjelenitesi_beallitasok, name = "egyik Landsat-kép")

egyik_landsat.bandNames().getInfo()
egyik_landsat.bandTypes()
egyik_landsat.bandTypes().getInfo().keys()
egyik_landsat.bandTypes().getInfo()["SR_B4"]

retegtartomany1 = egyik_landsat.slice(start = 5, end = 8)
retegtartomany1.bandNames().getInfo() # ['SR_B6', 'SR_B7', 'SR_QA_AEROSOL']
retegtartomany2 = egyik_landsat.slice(start = 15)
retegtartomany2.bandNames().getInfo() # ['ST_TRAD', 'ST_URAD', 'QA_PIXEL', 'QA_RADSAT']
retegtartomany3 = egyik_landsat.slice(start = -2)
retegtartomany3.bandNames().getInfo() # ['QA_PIXEL', 'QA_RADSAT']

valogatott_retegek1 = egyik_landsat.select(["SR_B4", "SR_B3", "SR_B2"])
valogatott_retegek1.bandNames().getInfo() # ['SR_B4', 'SR_B3', 'SR_B2']
valogatott_retegek2 = egyik_landsat.select([5, 8, 2])
valogatott_retegek2.bandNames().getInfo() # ['SR_B6', 'ST_B10', 'SR_B3']
valogatott_retegek2 = valogatott_retegek2.select(["SR_B6", "ST_B10"]) # SR_B3 törlése
valogatott_retegek2.bandNames().getInfo() # ['SR_B6', 'ST_B10']

valogatott_retegek2 = valogatott_retegek2.rename(["hatos", "tizes"]) # rétegek átnevezése
valogatott_retegek2.bandNames().getInfo() # ['hatos', 'tizes']

valogatott_retegek3 = egyik_landsat.select(["SR_B6", "ST_B10"], ["hatos", "tizes"]) # rétegek leválogatása és átnevezése
valogatott_retegek3.bandNames().getInfo() # ['hatos', 'tizes']

bovitett1 = valogatott_retegek3.addBands(srcImg = valogatott_retegek1)
bovitett1.bandNames().getInfo() # ['hatos', 'tizes', 'SR_B4', 'SR_B3', 'SR_B2']
bovitett2 = valogatott_retegek3.addBands(srcImg = valogatott_retegek1, names = ["SR_B4", "SR_B2"])
bovitett2.bandNames().getInfo() # ['hatos', 'tizes', 'SR_B4', 'SR_B2']

valogatott_retegek1.bandNames().getInfo() # ['SR_B4', 'SR_B3', 'SR_B2']
bovitett3 = valogatott_retegek1.addBands(srcImg = egyik_landsat.select(["SR_B2", "SR_B6"]), overwrite = True)
bovitett3.bandNames().getInfo() # ['SR_B4', 'SR_B3', 'SR_B2', 'SR_B6']
bovitett4 = valogatott_retegek1.addBands(srcImg = egyik_landsat.select(["SR_B2", "SR_B6"]), overwrite = False)
bovitett4.bandNames().getInfo() # ['SR_B4', 'SR_B3', 'SR_B2', 'SR_B2_1', 'SR_B6']
bovitett5 = valogatott_retegek1.addBands(srcImg = egyik_landsat.select(["SR_B2", "SR_B6"]))
bovitett5.bandNames().getInfo() # ['SR_B4', 'SR_B3', 'SR_B2', 'SR_B2_1', 'SR_B6']


