import ee
from ee_plugin import Map

Map.setCenter(lon = 20.65, lat = 47.6, zoom = 11) # Tisza-tó
kozeppont = Map.getCenter()

aprilis = ee.ImageCollection("LANDSAT/LC09/C02/T1_L2") \
	.filterBounds(kozeppont) \
	.filterDate("2023-04-01", "2023-04-30") \
	.first() \
	.select(["SR_B4", "SR_B3", "SR_B2"], ["piros", "zold", "kek"])
aprilis.bandNames().getInfo() # ['piros', 'zold', 'kek']
Map.addLayer(eeObject = aprilis, visParams = {"min": 5000, "max": 15000}, name = "áprilisi Landsat9-kép")

piros_reteg = aprilis.select("piros")
piros_reteg_negyzetgyoke = piros_reteg.sqrt().floor()
Map.addLayer(eeObject = piros_reteg_negyzetgyoke, visParams = {"min": 50, "max": 150}, name = "piros réteg négyzetgyökének alsó egészrésze")

osszes_reteg_negyzetgyoke = aprilis.sqrt().round()
osszes_reteg_negyzetgyoke.bandNames().getInfo() # ['piros', 'zold', 'kek']
Map.addLayer(eeObject = osszes_reteg_negyzetgyoke, visParams = {"min": 50, "max": 150}, name = "összes réteg négyzetgyöke kerekítve")

osszeg = aprilis.select("piros").add(aprilis.select("zold")).add(aprilis.select("kek"))
osszeg.bandNames().getInfo() # ['piros']
osszeg = osszeg.rename("osszeg")

atlag = osszeg.divide(3)
atlag.bandNames().getInfo() # ['osszeg']
atlag = atlag.rename("atlag")
aprilis_bovitett = aprilis.addBands(srcImg = atlag)
Map.addLayer(eeObject = aprilis_bovitett.select("atlag"), visParams = {"min": 5000, "max": 15000}, name = "rétegek átlaga")

majus = ee.ImageCollection("LANDSAT/LC09/C02/T1_L2") \
	.filterBounds(kozeppont) \
	.filterDate("2023-05-01", "2023-05-31") \
	.first() \
	.select(["SR_B4", "SR_B3", "SR_B2"], ["piros", "zold", "kek"])
Map.addLayer(eeObject = majus, visParams = {"min": 5000, "max": 15000}, name = "májusi Landsat9-kép")

elteres = aprilis.subtract(majus).abs()
Map.addLayer(eeObject = elteres, visParams = {"min": 0, "max": 1000}, name = "eltérés")

elteres_az_atlagtol = majus.subtract(atlag).abs()
Map.addLayer(eeObject = elteres_az_atlagtol, visParams = {"min": 0, "max": 1000}, name = "eltérés az áprilisi átlagtól")

zoldult = aprilis.select("zold").lte(majus.select("zold"))
Map.addLayer(eeObject = zoldult, visParams = {"min": 0, "max": 1}, name = "áprilisihez képest zöldült-e")

nagyon_kek = majus.select("kek").gte(10000)
nem_zoldult_vagy_kek = zoldult.Not().Or(nagyon_kek)
Map.addLayer(eeObject = nem_zoldult_vagy_kek, visParams = {"min": 0, "max": 1}, name = "ánem zöldült vagy nagyon kék")

